antares.apps.notifications package
==================================

Subpackages
-----------

.. toctree::

   antares.apps.notifications.console
   antares.apps.notifications.manager
   antares.apps.notifications.migrations
   antares.apps.notifications.models
   antares.apps.notifications.templatetags
   antares.apps.notifications.tests

Submodules
----------

antares.apps.notifications.admin module
---------------------------------------

.. automodule:: antares.apps.notifications.admin
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.notifications.apps module
--------------------------------------

.. automodule:: antares.apps.notifications.apps
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.notifications.constants module
-------------------------------------------

.. automodule:: antares.apps.notifications.constants
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: antares.apps.notifications
   :members:
   :undoc-members:
   :show-inheritance:
